enum StatementRule: string
Public API: explicitly declared with @visibility public.

Statement start rules available to SQLite SQL generation.

Values correspond to grammar rule names in SQLite's parse.y. The 'cmd' rule is the main statement entry point containing all SQL commands.

Enumerate the supported statement choicesdoctest
array_column(\SqlFaker\Sqlite\Generation\StatementRule::cases(), 'name') // => ['Select', 'Insert', 'Update', 'Delete', 'CreateTable', 'AlterTable', 'DropTable', 'SimpleStatement']
Use the existing StatementType aliasdoctest
\SqlFaker\Sqlite\StatementType::Select === \SqlFaker\Sqlite\Generation\StatementRule::Select // => true

Cases

case Select = 'select'
Public API: explicitly declared with @visibility public.
case Insert = 'insert'
Public API: explicitly declared with @visibility public.
case Update = 'update'
Public API: explicitly declared with @visibility public.
case Delete = 'delete'
Public API: explicitly declared with @visibility public.
case CreateTable = 'create_table'
Public API: explicitly declared with @visibility public.
case AlterTable = 'alter_table'
Public API: explicitly declared with @visibility public.
case DropTable = 'drop_table'
Public API: explicitly declared with @visibility public.
case SimpleStatement = 'cmd'
Public API: explicitly declared with @visibility public.

Test cases 4

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 2
Other tests reaching this symbol 2

Relations

Static calls 1
Constant reads 1
Type declarations 1